      subroutine read_files(pixels, start_view, end_view, dest, orient)

C     author: Hong Lin (linh@cs.purdue.edu)                        
C     date:   1998                                                 
C     
C     Driver for reading pixel frames from an external file.
C     
C     algorithm: Variable start_view marks the next pixel frame to be
C     read for processing. The root process reads (end_view-start_view+1)
C     pixel frames beginning from start_view and sends them to dest.
C     
C     Modification history:                                        
C     - Hong Lin, version 2.0, oct. 8, 1999                    
C     - Yongchang Ji, final version, aug.2000 -- jan. 2002
C     - RSS, general cleanup and modernization
      
      implicit none

      include 'mpif.h'
      include '../include/allprogs.inc'
      include '../include/info.inc'
      include '../include/pifhead.inc'

      type (pifhead_t) maphead, imghead
      common /pifhead/   maphead, imghead

      integer, intent(in) :: start_view, end_view, dest
      real, intent(in)    :: orient(0:9, max_views)
      real, intent(out)   :: pixels(npix_row, npix_col, view_perread)

      integer itemp, view, stat(mpi_status_size)
      character(len=10) :: subname = 'read_files'

      itemp  = npix_row*npix_col

      if (iam == 0) then
         do view = start_view, end_view
            imghead%imgnum = nint(orient(0, view))
            call pif_read_dh(imghead)
            imghead%lunum = pix_file_unit
            call rpifimag_f(itemp, pixels(1, 1, view - start_view + 1))
         enddo

         if (dest .ne. 0) then
            call mpi_send(pixels, view_perread*itemp, mpi_real,
     +           dest, dest, mpi_comm_world, mpi_err)
            if(mpi_err .ne. 0) then
               call error_stop(progname,subname,
     +              'error in calling mpi_send')
            endif
         endif
      else
         if (iam == dest) then
            call mpi_recv(pixels, view_perread*itemp, mpi_real,
     +           0, dest, mpi_comm_world, stat, mpi_err)
            if(mpi_err .ne. 0) then
               call error_stop(progname,subname,
     +              'error in calling mpi_recv')
            endif
         endif 
      endif
      
      return
      end subroutine read_files
