      subroutine pftcc_fill_g (pfts, pft_avgs, nrot, nannuli, nview_mod,
     $     sq2, jcut, pixres_min, pixres_max, ann_lo, ann_hi, var, rms,
     $     aver, varopt, sigcut)

c     december 1987  purdue university vax 11/750, t. baker
c     may 1992  purdue university vax 8550, j. tesmer
c     moved theta,phi calculations to calc_mod_tps, 30 jan 1997, d. belnap
c     modified 19-dec-1997 by t. baker (some output stuff)
c     modified 23-dec-1997 by t. baker (using memory for pfts)
c     modified 14-jan-1998 by tsb/rwa (*.pif input of pfts/prjs)
c     modified  6-mar-1998 by tsb (make unix compatible)
c     modified 27-apr-1998 by tsb (make global compatible)
c     modified 24-jul-2002 by tsb (pfts no longer store on disk)
c
c     modified 1-jan-2007 by rss (major cleanup of logic and bugfix
c     related to use of aver. In previous versions of routine, aver was
c     uninitialized on first call and accumulated results from previous
c     micrographs on subsequent calls.)
      
      implicit none
      
      integer, intent(in) :: nrot, nannuli, nview_mod, jcut
      integer, intent(in) :: ann_lo, ann_hi
      logical, intent(in) :: varopt
      real, intent(in)    :: sigcut, pixres_min, pixres_max
      real, intent(in)    :: pfts((nrot/4), nannuli, nview_mod)

      logical, intent(out) :: var((nrot/4), nannuli)
      real, intent(out)    :: rms((nrot/4), nannuli), sq2(nview_mod)
      real, intent(out)    :: pft_avgs(nview_mod)

      integer j, jn, k, j2, ir, r, num, nrot_by_4
      real aver((nrot/4),nannuli)
      real tmp2, pixres, pts, ave, ave2, pi, twopir

      pi = acos(-1.0)
      nrot_by_4 = nrot/4
      j2        = nrot_by_4 - 1
      pts       = 0.0

c     Initialize arrays var and aver depending on value of varopt

      if(varopt) then
         var = .false.          ! Fortran 90 array syntax
         aver = 0.0             ! Fortran 90 array syntax
      else
         var = .true.           ! Fortran 90 array syntax
      endif
      
      do k = 1,nview_mod
         pts = 0.0
         do ir = ann_lo,ann_hi
            r      = min(nannuli, ir+1)
            twopir = 2.0*pi*float(ir)
            do jn = jcut,j2
               if(jn > 0) then  ! trap for jo
                  pixres = twopir/float(jn)
               else
                  pixres = 1000.0
               endif
               if(pixres >= pixres_max .and. pixres <= pixres_min) then
                  j    = jn + 1
                  pts  = pts + 1.0
                  tmp2 = pfts(j,r,k)
                  if(varopt) then
                     aver(j,r) = aver(j,r) + tmp2
                  endif
               endif
            enddo
         enddo
      enddo
      
      ave2 = 0.0
      if(varopt) then
         do ir = ann_lo,ann_hi
            r      = min(nannuli, ir+1)
            twopir = 2.0*pi*float(ir)
            do jn = jcut,j2
               if(jn > 0) then  ! trap for jo
                  pixres = twopir/float(jn)
               else
                  pixres = 1000.0
               endif
               if(pixres >= pixres_max .and. pixres <= pixres_min) then
                  j        = jn + 1
                  rms(j,r) = 0.0
                  ave      = aver(j,r)/float(nview_mod)
                  do k = 1,nview_mod
                     tmp2     = pfts(j,r,k)
                     rms(j,r) = rms(j,r) + (tmp2-ave)**2
                  enddo
                  rms(j,r) = sqrt(rms(j,r)/nview_mod)
                  ave2     = ave2 + rms(j,r)
               endif
            enddo
         enddo

         num  = 0
         ave2 = ave2/pts
         do ir = ann_lo,ann_hi
            r      = min(nannuli, ir + 1)
            twopir = 2.0*pi*float(ir)
            do jn = jcut,j2
               if(jn > 0) then  ! trap for jo
                  pixres = twopir/float(jn)
               else
                  pixres = 1000.0
               endif
               if(pixres >= pixres_max .and. pixres <= pixres_min) then
                  j = jn + 1
                  if (rms(j,r) > sigcut*ave2) then
                     var(j,r) = .true.
                     num      = num + 1 
                  endif
               endif
            enddo
         enddo
         
         print *,'variance:'
         print *,'using points > ',sigcut,'*',ave2
         print *,'points from pfft being used: ',num
      endif
      
      do k = 1,nview_mod
         pts         = 0.0
         pft_avgs(k) = 0.0
         sq2(k)      = 0.0
         do ir = ann_lo,ann_hi
            r      = min(nannuli, ir+1)
            twopir = 2.0*pi*float(ir)
            do jn = jcut,j2
               if(jn > 0) then  ! trap for jo
                  pixres = twopir/float(jn)
               else
                  pixres = 1000.0
               endif
               if(pixres >= pixres_max .and. pixres <= pixres_min) then
                  j = jn + 1
                  if(var(j,r)) then
                     pts         = pts + 1.0
                     tmp2        = pfts(j,r,k)
                     pft_avgs(k) = pft_avgs(k) + tmp2
                     sq2(k)      = sq2(k) + tmp2**2
                  endif
               endif
            enddo
         enddo
         pft_avgs(k) = pft_avgs(k)/pts
      enddo
      
      return
      end subroutine pftcc_fill_g
